@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Meta CPAN API - ~/lib/Net/API/CPAN/List.pm
-## Version v0.1.0
+## Version v0.1.1
 ## Copyright(c) 2023 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2023/08/02
-## Modified 2023/08/02
+## Modified 2023/09/26
 ## All rights reserved
 ## 
 ## 
@@ -26,7 +26,7 @@ BEGIN
         # See <https://www.elastic.co/guide/en/elasticsearch/reference/2.4/search-request-from-size.html>
         DEFAULT_PAGE_SIZE => 10,
     };
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.1.1';
 };
 
 use strict;
@@ -506,7 +506,7 @@ sub next
                 if( !scalar( keys( %$query ) ) || 
                     ( !exists( $query->{page} ) && !exists( $query->{from} ) && !exists( $query->{size} ) ) )
                 {
-                    return( $self->error( "No search query set." ) );
+                    # return( $self->error( "No search query set." ) );
                 }
                 $size = $self->size;
                 # If size option is set, otherwise we leave it out
@@ -785,7 +785,7 @@ Net::API::CPAN::List - Meta CPAN API List
 
 =head1 VERSION
 
-    v0.1.0
+    v0.1.1
 
 =head1 DESCRIPTION
 
